@@ -35,7 +35,7 @@ def complexity_delay(signal, delay_max=100, method="fraser1986", show=False):
 
     Parameters
     ----------
-    signal : list or array or Series
+    signal : Union[list, np.array, pd.Series]
         The signal (i.e., a time series) in the form of a vector of values.
     delay_max : int
         The maximum time delay (Tau or lag) to test.
@@ -68,7 +68,7 @@ def complexity_delay(signal, delay_max=100, method="fraser1986", show=False):
     >>>
     >>> # Realistic example
     >>> ecg = nk.ecg_simulate(duration=60*6, sampling_rate=150)
-    >>> signal = nk.ecg_rate(nk.ecg_peaks(ecg, sampling_rate=150), sampling_rate=150)
+    >>> signal = nk.ecg_rate(nk.ecg_peaks(ecg, sampling_rate=150), sampling_rate=150, desired_length=len(ecg))
     >>> nk.signal_plot(signal)
     >>>
     >>> delay = nk.complexity_delay(signal, delay_max=1000, show=True)
