@@ -14,7 +14,7 @@ def entropy_shannon(signal):
 
     Parameters
     ----------
-    signal : list, array or Series
+    signal : Union[list, np.array, pd.Series]
         The signal (i.e., a time series) in the form of a vector of values.
 
 
