@@ -30,7 +30,7 @@ def ecg_rsp(ecg_rate, sampling_rate=1000, method="vangent2019"):
     >>> # Get heart rate
     >>> data = nk.data("bio_eventrelated_100hz")
     >>> rpeaks, info = nk.ecg_peaks(data["ECG"], sampling_rate=100)
-    >>> ecg_rate = nk.signal_rate(rpeaks, sampling_rate=100)
+    >>> ecg_rate = nk.signal_rate(rpeaks, sampling_rate=100, desired_length=len(rpeaks))
     >>>
     >>>
     >>> # Get ECG Derived Respiration (EDR)
