@@ -10,7 +10,7 @@ def eda_autocor(eda_cleaned, sampling_rate=1000, lag=4):
 
     Parameters
     ----------
-    eda_cleaned : list or array or Series
+    eda_cleaned : Union[list, np.array, pd.Series]
         The cleaned EDA signal.
     sampling_rate : int
         The sampling frequency of raw EDA signal (in Hz, i.e., samples/second). Defaults to 1000Hz.
