@@ -2,6 +2,7 @@
 
 from .mne_channel_add import mne_channel_add
 from .mne_channel_extract import mne_channel_extract
+from .mne_to_df import mne_to_df, mne_to_dict
 
 
-__all__ = ["mne_channel_add", "mne_channel_extract"]
+__all__ = ["mne_channel_add", "mne_channel_extract", "mne_to_df", "mne_to_dict"]
