@@ -8,7 +8,7 @@ def emg_intervalrelated(data):
 
     Parameters
     ----------
-    data : DataFrame, dict
+    data : Union[dict, pd.DataFrame]
         A DataFrame containing the different processed signal(s) as different columns, typically generated
         by `emg_process()` or `bio_process()`. Can also take a dict containing sets of separately
         processed DataFrames.
@@ -84,8 +84,7 @@ def emg_intervalrelated(data):
 
 
 def _emg_intervalrelated_formatinput(interval, output={}):
-    """Format input for dictionary.
-    """
+    """Format input for dictionary."""
     # Sanitize input
     colnames = interval.columns.values
     if len([i for i in colnames if "EMG_Onsets" in i]) == 0:
