@@ -2,6 +2,7 @@
 import matplotlib.pyplot as plt
 import numpy as np
 import pandas as pd
+import scipy.stats
 
 from ..stats import mad, summary_plot
 from .hrv_utils import _hrv_get_rri, _hrv_sanitize_input
@@ -27,25 +28,27 @@ def hrv_time(peaks, sampling_rate=1000, show=False):
     -------
     DataFrame
         Contains time domain HRV metrics:
-        - "*RMSSD*": the square root of the mean of the sum of successive differences between
-        adjacent RR intervals.
-        - "*MeanNN*": the mean of the RR intervals.
-        - "*SDNN*": the standard deviation of the RR intervals.
-        - "*SDSD*": the standard deviation of the successive differences between RR intervals.
-        - "*CVNN*": the standard deviation of the RR intervals (SDNN) divided by the mean of the RR
+        - **RMSSD**: The square root of the mean of the sum of successive differences between
+        adjacent RR intervals. It is equivalent (although on another scale) to SD1, and
+        therefore it is redundant to report correlations with both (Ciccone, 2017).
+        - **MeanNN**: The mean of the RR intervals.
+        - **SDNN**: The standard deviation of the RR intervals.
+        - **SDSD**: The standard deviation of the successive differences between RR intervals.
+        - **CVNN**: The standard deviation of the RR intervals (SDNN) divided by the mean of the RR
         intervals (MeanNN).
-        - "*CVSD*": the root mean square of the sum of successive differences (RMSSD) divided by the
+        - **CVSD**: The root mean square of the sum of successive differences (RMSSD) divided by the
         mean of the RR intervals (MeanNN).
-        - "*MedianNN*": the median of the absolute values of the successive differences between RR intervals.
-        - "*MadNN*": the median absolute deviation of the RR intervals.
-        - "*HCVNN*": the median absolute deviation of the RR intervals (MadNN) divided by the median
+        - **MedianNN**: The median of the absolute values of the successive differences between RR intervals.
+        - **MadNN**: The median absolute deviation of the RR intervals.
+        - **HCVNN**: The median absolute deviation of the RR intervals (MadNN) divided by the median
         of the absolute differences of their successive differences (MedianNN).
-        - "*pNN50*": the proportion of RR intervals greater than 50ms, out of the total number of RR intervals.
-        - "*pNN20*": the proportion of RR intervals greater than 20ms, out of the total number of RR intervals.
-        - "*TINN*": a geometrical parameter of the HRV, or more specifically, the baseline width of
+        - **IQRNN**: The interquartile range (IQR) of the RR intervals.
+        - **pNN50**: The proportion of RR intervals greater than 50ms, out of the total number of RR intervals.
+        - **pNN20**: The proportion of RR intervals greater than 20ms, out of the total number of RR intervals.
+        - **TINN**: A geometrical parameter of the HRV, or more specifically, the baseline width of
         the RR intervals distribution obtained by triangular interpolation, where the error of least
         squares determines the triangle. It is an approximation of the RR interval distribution.
-        - "*HTI*": the HRV triangular index, measuring the total number of RR intervals divded by the
+        - **HTI**: The HRV triangular index, measuring the total number of RR intervals divded by the
         height of the RR intervals histogram.
 
     See Also
@@ -67,8 +70,13 @@ def hrv_time(peaks, sampling_rate=1000, show=False):
 
     References
     ----------
+    - Ciccone, A. B., Siedlik, J. A., Wecht, J. M., Deckert, J. A., Nguyen, N. D., & Weir, J. P.
+    (2017). Reminder: RMSSD and SD1 are identical heart rate variability metrics. Muscle & nerve,
+    56(4), 674-678.
+
     - Stein, P. K. (2002). Assessing heart rate variability from real-world Holter reports. Cardiac
     electrophysiology review, 6(3), 239-244.
+
     - Shaffer, F., & Ginsberg, J. P. (2017). An overview of heart rate variability metrics and norms.
     Frontiers in public health, 5, 258.
 
@@ -89,13 +97,15 @@ def hrv_time(peaks, sampling_rate=1000, show=False):
     out["SDNN"] = np.nanstd(rri, ddof=1)
     out["SDSD"] = np.nanstd(diff_rri, ddof=1)
 
+    # Normalized
     out["CVNN"] = out["SDNN"] / out["MeanNN"]
     out["CVSD"] = out["RMSSD"] / out["MeanNN"]
 
     # Robust
     out["MedianNN"] = np.nanmedian(rri)
     out["MadNN"] = mad(rri)
-    out["MCVNN"] = out["MadNN"] / out["MedianNN"]
+    out["MCVNN"] = out["MadNN"] / out["MedianNN"]  # Normalized
+    out["IQRNN"] = scipy.stats.iqr(rri)
 
     # Extreme-based
     nn50 = np.sum(np.abs(diff_rri) > 50)
