@@ -2,8 +2,9 @@
 
 from .expspace import expspace
 from .find_closest import find_closest
+from .find_consecutive import find_consecutive
 from .listify import listify
 from .type_converters import as_vector
 
 
-__all__ = ["listify", "find_closest", "as_vector", "expspace"]
+__all__ = ["listify", "find_closest", "find_consecutive", "as_vector", "expspace"]
