@@ -20,7 +20,7 @@ def signal_filter(
 
     Parameters
     ----------
-    signal : list or array or Series
+    signal : Union[list, np.array, pd.Series]
         The signal (i.e., a time series) in the form of a vector of values.
         or "bandstop".
     sampling_rate : int
@@ -160,8 +160,7 @@ def _signal_filter_savgol(signal, sampling_rate=1000, order=2, window_size="defa
 # FIR
 # =============================================================================
 def _signal_filter_fir(signal, sampling_rate=1000, lowcut=None, highcut=None, window_size="default"):
-    """Filter a signal using a FIR filter.
-    """
+    """Filter a signal using a FIR filter."""
     try:
         import mne
     except ImportError:
@@ -197,8 +196,7 @@ def _signal_filter_fir(signal, sampling_rate=1000, lowcut=None, highcut=None, wi
 
 
 def _signal_filter_butterworth(signal, sampling_rate=1000, lowcut=None, highcut=None, order=5):
-    """Filter a signal using IIR Butterworth SOS method.
-    """
+    """Filter a signal using IIR Butterworth SOS method."""
     freqs, filter_type = _signal_filter_sanitize(lowcut=lowcut, highcut=highcut, sampling_rate=sampling_rate)
 
     sos = scipy.signal.butter(order, freqs, btype=filter_type, output="sos", fs=sampling_rate)
@@ -207,8 +205,7 @@ def _signal_filter_butterworth(signal, sampling_rate=1000, lowcut=None, highcut=
 
 
 def _signal_filter_butterworth_ba(signal, sampling_rate=1000, lowcut=None, highcut=None, order=5):
-    """Filter a signal using IIR Butterworth B/A method.
-    """
+    """Filter a signal using IIR Butterworth B/A method."""
     # Get coefficients
     freqs, filter_type = _signal_filter_sanitize(lowcut=lowcut, highcut=highcut, sampling_rate=sampling_rate)
 
@@ -240,9 +237,8 @@ def _signal_filter_bessel(signal, sampling_rate=1000, lowcut=None, highcut=None,
 
 
 def _signal_filter_powerline(signal, sampling_rate, powerline=50):
-    """Filter out 50 Hz powerline noise by smoothing the signal with a moving average kernel with the width of one period
-    of 50Hz.
-    """
+    """Filter out 50 Hz powerline noise by smoothing the signal with a moving average kernel with the width of one
+    period of 50Hz."""
 
     if sampling_rate >= 100:
         b = np.ones(int(sampling_rate / powerline))
