@@ -1,5 +1,4 @@
-"""Submodule for NeuroKit.
-"""
+"""Submodule for NeuroKit."""
 
 from .correlation import cor
 from .density import density
